@@ -29,7 +29,7 @@ else
  JAVA_CMD=$JAVA_HOME/bin/java
 fi
 
-$JAVA_CMD -cp bin/flyway-commandline-2.0.jar:bin/flyway-core-2.0.jar:bin/spring-jdbc-2.5.6.jar:bin/commons-logging-1.1.1.jar:bin/spring-beans-2.5.6.jar:bin/spring-core-2.5.6.jar:bin/spring-context-2.5.6.jar:bin/aopalliance-1.0.jar:bin/spring-tx-2.5.6.jar:bin/log4j-1.2.16.jar:sql com.googlecode.flyway.commandline.Main $@
+$JAVA_CMD -cp bin/flyway-commandline-2.0.2.jar:bin/flyway-core-2.0.2.jar:bin/spring-jdbc-2.5.6.jar:bin/commons-logging-1.1.1.jar:bin/spring-beans-2.5.6.jar:bin/spring-core-2.5.6.jar:bin/spring-context-2.5.6.jar:bin/aopalliance-1.0.jar:bin/spring-tx-2.5.6.jar:bin/log4j-1.2.16.jar:sql com.googlecode.flyway.commandline.Main $@
 
 # Save the exit code
 JAVA_EXIT_CODE=$?
